@@ -82,7 +82,6 @@ class SixRateLimiterMiddleware(BaseHTTPMiddleware):
         timestamp = time.time()
         last_log_sent = self._rate_limit_logs_sent[route]
         if timestamp - last_log_sent > 10:
-            print("called from here")
             requests.post("https://backend.withsix.co/slack/send_message_to_slack_user", json=schemas.SlackMessageSchema(
                 header=header, 
                 user_id=self._apikey, 
@@ -169,7 +168,6 @@ class SixRateLimiterMiddleware(BaseHTTPMiddleware):
                         _response = await call_next(request)
                         return _response
                 except Exception as e:
-                    print(e)
                     _response = await call_next(request)
                     return _response
             else:
@@ -177,6 +175,6 @@ class SixRateLimiterMiddleware(BaseHTTPMiddleware):
                 _response = await call_next(request)
                 return _response
         except Exception as e:
-            print(e)
+            
             _response = await call_next(request)
             return _response
\ No newline at end of file
